#!/usr/bin/env python
import math
"""List of all constants available

Call function tiquations.help for more info
"""
pi = math.pi
eulersnum= math.e
tau = math.tau
eulersmasch = 0.577215664901532860606512
golden_ratio = 1.6180339887498948420
light_speed = 299792458
avogadro = 6.02214076e23
boltzmann = 1.380649e-23
gas_constant = 8.314462618
luminous_efficacy= 683
atmosphere=101325
speed_of_light = 299792458
planck=6.62607004e-34
