#!/usr/bin/env python
class Elements(object):
    """Information about elements in the periodic table

    Features:
    symbol - String
    atomic_mass - Float
    atomic_number - Integer

    Example: carbon.atomic_mass
    """
    def __init__(self,symbol,atomic_mass,atomic_number):
        self.symbol=symbol
        self.atomic_mass=atomic_mass
        self.atomic_number=atomic_number

hydrogen=Elements("H",1.00794,1)
helium=Elements("He",4.002602,2)
lithium=Elements("Li",6.941,3)
beryllium=Elements("Be",9.012182,4)
boron=Elements("B",10.811,5)
carbon=Elements("C",12.0107,6)
nitrogen=Elements("N",14.0067,7)
oxygen=Elements("O",15.9994,8)
fluorine=Elements("F",18.9984032,9)
neon=Elements("Ne",20.1797,10)
sodium=Elements("Na",22.98977,11)
magnesium=Elements("Mg",24.305,12)
aluminum=Elements("Al",26.981538,13)
silicon=Elements("Si",28.0855,14)
phosphorus=Elements("P",30.973761,15)
sulfur=Elements("S",32.065,16)
chlorine=Elements("Cl",35.453,17)
argon=Elements("Ar",39.948,18)
potassium=Elements("K",39.0983,19)
calcium=Elements("Ca",40.078,20)
scandium=Elements("Sc",44.95591,21)
titanium=Elements("Ti",47.867,22)
vanadium=Elements("V",50.9415,23)
chromium=Elements("Cr",51.9961,24)
manganese=Elements("Mn",54.938049,25)
iron=Elements("Fe",55.845,26)
cobalt=Elements("Co",58.9332,27)
nickel=Elements("Ni",58.6934,28)
copper=Elements("Cu",63.546,29)
zinc=Elements("Zn",65.409,30)
gallium=Elements("Ga",69.723,31)
germanium=Elements("Ge",72.64,32)
arsenic=Elements("As",74.9216,33)
selenium=Elements("Se",78.96,34)
bromine=Elements("Br",79.904,35)
krypton=Elements("Kr",83.798,36)
rubidium=Elements("Rb",85.4678,37)
strontium=Elements("Sr",87.62,38)
yttrium=Elements("Y",88.90585,39)
zirconium=Elements("Zr",91.224,40)
niobium=Elements("Nb",92.90638,41)
molybdenum=Elements("Mo",95.94,42)
technetium=Elements("Tc",98,43)
ruthenium=Elements("Ru",101.07,44)
rhodium=Elements("Rh",102.9055,45)
palladium=Elements("Pd",106.42,46)
silver=Elements("Ag",107.8682,47)
cadmium=Elements("Cd",112.411,48)
indium=Elements("In",114.818,49)
tin=Elements("Sn",118.71,50)
antimony=Elements("Sb",121.76,51)
tellurium=Elements("Te",127.6,52)
iodine=Elements("I",126.90447,53)
xenon=Elements("Xe",131.293,54)
cesium=Elements("Cs",132.90545,55)
barium=Elements("Ba",137.327,56)
lanthanum=Elements("La",138.9055,57)
cerium=Elements("Ce",140.116,58)
praseodymium=Elements("Pr",140.90765,59)
neodymium=Elements("Nd",144.24,60)
promethium=Elements("Pm",145,61)
samarium=Elements("Sm",150.36,62)
europium=Elements("Eu",151.964,63)
gadolinium=Elements("Gd",157.25,64)
terbium=Elements("Tb",158.92534,65)
dysprosium=Elements("Dy",162.5,66)
holmium=Elements("Ho",164.93032,67)
erbium=Elements("Er",167.259,68)
thulium=Elements("Tm",168.93421,69)
ytterbium=Elements("Yb",173.04,70)
lutetium=Elements("Lu",174.967,71)
hafnium=Elements("Hf",178.49,72)
tantalum=Elements("Ta",180.9479,73)
tungsten=Elements("W",183.84,74)
rhenium=Elements("Re",186.207,75)
osmium=Elements("Os",190.23,76)
iridium=Elements("Ir",192.217,77)
platinum=Elements("Pt",195.078,78)
gold=Elements("Au",196.96655,79)
mercury=Elements("Hg",200.59,80)
thallium=Elements("Tl",204.3833,81)
lead=Elements("Pb",207.2,82)
bismuth=Elements("Bi",208.98038,83)
polonium=Elements("Po",209,84)
astatine=Elements("At",210,85)
radon=Elements("Rn",222,86)
francium=Elements("Fr",223,87)
radium=Elements("Ra",226,88)
actinium=Elements("Ac",227,89)
thorium=Elements("Th",232.0381,90)
protactinium=Elements("Pa",231.03588,91)
uranium=Elements("U",238.02891,92)
neptunium=Elements("Np",237,93)
plutonium=Elements("Pu",244,94)
americium=Elements("Am",243,95)
curium=Elements("Cm",247,96)
berkelium=Elements("Bk",247,97)
californium=Elements("Cf",251,98)
einsteinium=Elements("Es",252,99)
fermium=Elements("Fm",257,100)
mendelevium=Elements("Md",258,101)
nobelium=Elements("No",259,102)
lawrencium=Elements("Lr",262,103)
rutherfordium=Elements("Rf",261,104)
dubnium=Elements("Db",262,105)
seaborgium=Elements("Sg",266,106)
bohrium=Elements("Bh",264,107)
hassium=Elements("Hs",277,108)
meitnerium=Elements("Mt",268,109)
darmstadtium=Elements("Ds",281,110)
roentgenium=Elements("Rg",272,111)
copernicium=Elements("Cn",285,112)
nihonium=Elements("Nh",286,113)
flerovium=Elements("Fl",289,114)
moscovium=Elements("Mc",289,115)
livermorium=Elements("Lv",293,116)
tennessine=Elements("Ts",294,117)
oganesson=Elements("Og",294,118)
